@@ -5,7 +5,7 @@ use warnings;
 package portable::lib;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use FindBin qw($Bin);
 push @portable::INC, $Bin;
@@ -16,14 +16,4 @@ sub import {
 	push @portable::INC, map { (my $fn = $_) =~ s(/$)(); $fn } @_;
 }
 
-sub search_inc {
-	my $me = shift;
-	my ($filename) = @_;
-	for my $dir (@portable::INC) {
-		my $qualified = "$dir/$filename";
-		return $qualified if -f $qualified;
-	}
-	return undef;
-}
-
 1;
